#delimit ;;
*************************************************************
*                                                           *
*    Name    : CALCNF1X.DO                V : 02            *
*    Date    : 21 SEP 1999                                  *
*    Infile  : REGEXP, HHID                                 *
*    Outfile : NF1X01                                       *
*                                                           *
*    OBJECTIVE: Calculate total household monthly           *
*               expenditure on regular non-food commodities *
*               including energy (Section 4.1)              *
*                                                           *
*               Cluster, race, item medians used to impute  *
*               missing values unless otherwise noted       *
*                                                           *
*************************************************************;;

global IN  = "i:\fcn\shared\mp17\safrica\survey98\data\origv2";
global OUT = "i:\fcn\shared\mp17\safrica\survey98\data\consv1";

use $IN\regexp , clear ;

** Merge with HHID to get clustnum and race variables                   **;;

merge hhid using $IN\hhid ;
assert _merge == 3 ; drop _merge ;

** Construct 0/1 flag for missing values                                **;;

gen byte flagreg = ( rnfs_a < 0 ) ;

** Calculate cluster & race medians of nonzero purchases                **;;

egen medpval= median(rnfs_a) if (rnfs_a>0), by(rnfs_c clustnum race) ; 
egen medval = min(medpval),                 by(rnfs_c clustnum race) ; 

** List the households and items with missing values and the            **
** corresponding median values for imputations                          **;;

li hhid rnfs_c medval if flagreg , noobs nolabel ;


**----------------------------------------------------------------------**
** Replace missing observations with cluster & race medians             **
**----------------------------------------------------------------------**;;


** (1) Water, Electricity, and Municipal Rates measures                 **;;

gen     energy1 = rnfs_a if rnfs_c==14 & flagreg == 0 ;
replace energy1 = medval if rnfs_c==14 & flagreg == 1 ;

** Median for cluster with missing rnfs_c=14 is also missing so use     **
** sum of medians for rnfs_c=15,16,& 17 in same cluster = 35 Rand       **;;

replace energy1 = 35   if rnfs_c == 14 & flagreg == 1 & clustnum == 76 ;

gen     water = rnfs_a if rnfs_c == 15 & flagreg == 0 ;
replace water = medval if rnfs_c == 15 & flagreg == 1 ;

gen     elec = rnfs_a  if rnfs_c == 16 & flagreg == 0 ;
replace elec = medval  if rnfs_c == 16 & flagreg == 1 ;

gen     muni = rnfs_a  if rnfs_c == 17 & flagreg == 0 ;
replace muni = medval  if rnfs_c == 17 & flagreg == 1 ;

** Calculate combined energy, water, municipal rates at household level **;;

** Combined Expenditure (rnfs_c=14)                                     **;;

egen energy1h = sum(energy1), by (hhid) ;

** Components of expenditure (rnfs_c=15,16,17)                          **;;

egen water_h  = sum(water), by (hhid) ;
egen elec_h   = sum(elec) , by (hhid) ;
egen muni_h   = sum(muni) , by (hhid) ;

gen add       = water_h + elec_h + muni_h ;

** Construct variable MXEWR which is sum of household expenditure on    **
** water + electricity + municipal rates regardless of whether reported **
** as combined (rnfs_c==14) or individual categories (rnfs_c= 15-17)    **;;

gen mxewr     = add ;
replace mxewr = energy1h if add == 0 ;

drop energy1* water* elec* muni* ;;;


** (2) Non-Fuel measures i.e. other expenditures                        **;;

** Median for cluster with missing rnfs_c=18 is also missing so fill in **
** with overall median for rnfs_c=18 which is 30 Rand                   **;;

replace rnfs_a = 30 if rnfs_c == 18 & flagreg == 1 & clustnum == 73 ;

** The following program constructs temporary variables to calculate    **
** household level expenditures, replacing missing values with medians  **;;

program define fillmedn ;

 while "`1'"~="" { ;

   gen com`1'=rnfs_a       if rnfs_c==`1' & flagreg==0 ;
   replace com`1' = medval if rnfs_c==`1' & flagreg==1 ;
 
   mac shift         ;
   
   }                 ;

end ;


fillmedn 1 2 3 4 5 6 7 8 9 10 11 12 13 18 ;

                                   
** Calculate the other non-food expenditures at the household level     ** 
** using the temporary variables constructed above.                     **
** Note: The "egen & summ" command turns missing values into zeros      **;;

egen mxcig   = sum(com1) , by (hhid) ;
egen mxalc   = sum(com2) , by (hhid) ;
egen mxent   = sum(com3) , by (hhid) ;
egen mxpcare = sum(com4) , by (hhid) ;
egen mxnews  = sum(com5) , by (hhid) ;
egen mxtel   = sum(com6) , by (hhid) ;
egen mxcar   = sum(com7) , by (hhid) ;
egen mxtran1  = sum(com8) , by (hhid) ;                  
egen mxwash  = sum(com9) , by (hhid) ;
egen mxchil  = sum(com10), by (hhid) ;
egen mxdues  = sum(com11), by (hhid) ;
egen mxdon   = sum(com12), by (hhid) ;
egen mxhelp  = sum(com13), by (hhid) ;
egen mxener  = sum(com18), by (hhid) ;

** Calculate total monthly regular non-food expenditure for household   **;;

gen mxtot   = mxcig + mxalc + mxent + mxpcare + mxnews + mxtel + mxcar + 
              mxtran1 + mxwash + mxchil + mxdues + mxdon + mxhelp + 
              mxener + mxewr ;

** Label Variables                                                      **;;

label data "1998 Regular Non-Food Expenditures" ;

label var mxcig   "98: Month exp: Cigs & Tobacco" ;
label var mxalc   "98: Month exp: Alcohol" ;
label var mxent   "98: Month exp: Entertainment" ;
label var mxpcare "98: Month exp: Personal Care" ;
label var mxnews  "98: Month exp: Newspapers" ;
label var mxtel   "98: Month exp: Telephone" ;
label var mxcar   "98: Month exp: Vehicle" ;
label var mxtran1 "98: Month exp: Transportation" ;
label var mxwash  "98: Month exp: Washing Supplies" ;
label var mxchil  "98: Month exp: Day Care" ;
label var mxdues  "98: Month exp: Dues" ;
label var mxdon   "98: Month exp: Donations" ;
label var mxhelp  "98: Month exp: Household Help" ;
label var mxener  "98: Month exp: Other Energy" ;
label var mxewr   "98: Month exp: H2O,elec & rates" ;
label var mxtot   "98: Month exp: Total non-food" ;
label var flagreg "98: (1) if any exp item imputed" ;

  
** Construct household level file, sort to retain non-zero flags        **;;

drop rnfs_c rnfs_a medval medpval com* add race clustnum ;
gsort + hhid - flag ;
quietly by hhid: keep if _n==1 ;

notes drop _dta ;
order hhid mxewr mxcig mxalc mxent mxpcare mxnews mxtel mxcar mxtran1
 mxwash mxchil mxdues mxdon mxhelp mxener mxtot flag ;
sort hhid ;
save $OUT\nf1x01, replace ;         

summ ;  
desc ; 
            
exit;




    

