#delimit ;;
*************************************************************
*                                                           *
*    Name    : FOODEXP.DO               V : 02              *
*    Date    : 21 SEP 1999                                  *
*    Infile  : FOODCN, HHID                                 *
*    Outfile : FOODEXP                                      *
*                                                           *
*    OBJECTIVE: Calculate total household monthly           * 
*               expenditure on food (Section 3)             *
*                                                           *
*               Cluster, race, item medians used to impute  *
*               missing values unless otherwise noted       *
*                                                           *
*               Note: Various "meals" categories (mealgave  *
*               and mealgot) included in "other", rather    *
*               than separately as in 1993. Additional      *
*               variables for these are kept in FOODEXP     *
*               for researchers who want to separate them   *
*               out.                                        *
*                                                           *
*************************************************************;

global IN  = "I:\fcn\shared\mp17\safrica\survey98\data\origv2";
global OUT = "I:\fcn\shared\mp17\safrica\survey98\data\consv1";

use $IN\foodcn , clear ;         

** Merge with HHID to get clustnum and race variables                   **;;

merge hhid using $IN\hhid ;
assert _merge == 3 ; drop _merge ;

** Construct 0/1 flag for missing values                                **;;

gen byte flagfood = ( purchasd < 0 ) ;

**  Calculate cluster & race medians of nonzero purchases               **;;

egen medpval = median(purchasd) if purchasd>0, by(foodcode clustnum race) ;
egen medval  = min(medpval),                   by(foodcode clustnum race) ;

** List the households and items with missing values and the            **
** corresponding median values for imputations                          **;;

li hhid foodcode medval if flagfood, noobs nolabel ;

** Replace missing observations with cluster & race medians             **;;

replace purchasd = medval if flagfood ;

** Calculate total expenditures for each food item                      **;;

gen mxtfood = purchasd + gift + payment + ownprod ;

** Calculate total expenditures for food categories                     **;;

** Assignments to food type categories made as follows                  **
**
**      Food type       name            codes included
**      ---------       ----            --------------
**
**      Grains          grain           1 2 3 4 5 6
**      Fruit/Veggies   fruve           7 8 9 10 23 24 25 26 27 33
**      Oil/Fats        oils            11 12
**      Dairy           dairy           13 15 16
**      Sugar           sugar           17
**      Meat/Fish       meafi           18 19 20 21 22 32
**      Other           other           14 28 29 30 31 34
**                                                                      **;;

gen mxgrain   = mxtfood if  foodcode<=6;

gen mxfruve   = mxtfood if (foodcode>= 7 & foodcode<=10)
                       |(foodcode>=23 & foodcode<=27)| foodcode==33 ;

gen mxoils    = mxtfood if (foodcode==11 | foodcode==12) ;

gen mxdairy   = mxtfood if (foodcode==13 | foodcode==15 | foodcode==16) ;

gen mxsugar   = mxtfood if  foodcode==17 ;

gen mxmeafi   = mxtfood if (foodcode>=18 & foodcode<=22)| foodcode==32 ;

gen mxother   = mxtfood if (foodcode==14 | foodcode==28 | foodcode==29 |
                         foodcode==30 | foodcode==31 | foodcode==34) ;

gen mealgot   = mxtfood if foodcode==30 ;
gen mealgave  = mxtfood if foodcode==34 ;

collapse (sum) mxpurch=purchasd mxgift=gift mxpay=payment
               mxownprd=ownprod mxgrain mxfruve  mxoils mxdairy
               mxsugar mxmeafi mxother flagfood mxtfood 
               mealgave mealgot
               ,  by(hhid) ;

** Verify calculations                                                  **;;

gen check = mxgrain + mxfruve + mxoils + mxdairy + mxsugar + mxmeafi + 
            mxother;
            
assert mxtfood == check ; drop check ;

** Calculate % Food shares                                              **;;

gen sxgrain = 100 * mxgrain / mxtfood if mxtfood > 0 ;
gen sxfruve = 100 * mxfruve / mxtfood if mxtfood > 0 ;
gen sxoils  = 100 * mxoils  / mxtfood if mxtfood > 0 ;
gen sxdairy = 100 * mxdairy / mxtfood if mxtfood > 0 ;
gen sxsugar = 100 * mxsugar / mxtfood if mxtfood > 0 ;
gen sxmeafi = 100 * mxmeafi / mxtfood if mxtfood > 0 ;
gen sxother = 100 * mxother / mxtfood if mxtfood > 0 ;

** Label Variables                                                      **;;

label data "1998 Food Expenditures" ;

label var mxtfood   "98: Tot month food exp";
label var mxpurch   "98: Tot month food purchased";
label var mxgift    "98: Tot month food gifts";
label var mxpay     "98: Tot month food payment";
label var mxownprd  "98: Tot month food production";
label var mxgrain   "98: Tot month exp: grains";
label var mxfruve   "98: Tot month exp: fruit/veg";
label var mxoils    "98: Tot month exp: butter/oil";
label var mxdairy   "98: Tot month exp: dairy";
label var mxsugar   "98: Tot month exp: sugar";
label var mxmeafi   "98: Tot month exp: meat";
label var mxother   "98: Tot month exp: other + meals gave/got";
label var mealgave  "98: Tot month exp: meals given" ;
label var mealgot   "98: Tot month exp: meals receivd" ;
label var flagfood  "98: (1) if food item imputed";
label var sxgrain   "98: % Food share : grains";
label var sxfruve   "98: % Food share : fruit/veg";
label var sxoils    "98: % Food share : butter/oil";
label var sxdairy   "98: % Food share : dairy";
label var sxsugar   "98: % Food share : sugar";
label var sxmeafi   "98: % Food share : meat";
label var sxother   "98: % Food share : other";


notes drop _all ;
notes : HH 730190 eats with sister's HH and contributes 600 per month ;

sort hhid ;
save $OUT\foodexp, replace ;

desc ;
summ ;


exit ;
